@@ -9,20 +9,20 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.4.") or
-    raise "ruby lib version (2.4.10) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.6.") or
+    raise "ruby lib version (2.6.2) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.4.0/x86_64-linux")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.6.0/x86_64-linux")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "10"
-  CONFIG["PATCHLEVEL"] = "364"
+  CONFIG["MINOR"] = "6"
+  CONFIG["TEENY"] = "2"
+  CONFIG["PATCHLEVEL"] = "47"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr")
@@ -30,12 +30,11 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.4.pc"
+  CONFIG["ruby_pc"] = "ruby-2.6.pc"
+  CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
-  CONFIG["USE_RUBYGEMS"] = "YES"
   CONFIG["MANTYPE"] = "doc"
-  CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["vendorarchhdrdir"] = "$(vendorhdrdir)/$(sitearch)"
   CONFIG["sitearchhdrdir"] = "$(sitehdrdir)/$(sitearch)"
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
@@ -45,7 +44,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt'"
+  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +54,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.4.0"
+  CONFIG["ruby_version"] = "2.6.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-linux"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -78,28 +77,32 @@ module RbConfig
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["COMMON_MACROS"] = ""
   CONFIG["COMMON_LIBS"] = ""
-  CONFIG["MAINLIBS"] = ""
+  CONFIG["MAINLIBS"] = "-lz -lpthread -lrt -lrt -lgmp -ldl -lcrypt -lm "
   CONFIG["ENABLE_SHARED"] = "yes"
+  CONFIG["DLDSHARED"] = "$(CC) -shared"
   CONFIG["DLDLIBS"] = " -lc"
-  CONFIG["SOLIBS"] = "$(LIBS)"
+  CONFIG["SOLIBS"] = "$(MAINLIBS)"
   CONFIG["LIBRUBYARG_SHARED"] = "-l$(RUBY_SO_NAME)"
-  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
+  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static $(MAINLIBS)"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
-  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so.$(MAJOR).$(MINOR) lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.$(RUBY_PROGRAM_VERSION)"
+  CONFIG["LIBRUBY_ALIASES"] = "$(LIBRUBY_SONAME) lib$(RUBY_SO_NAME).$(SOEXT)"
+  CONFIG["LIBRUBY_SONAME"] = "lib$(RUBY_SO_NAME).$(SOEXT).$(RUBY_API_VERSION)"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).$(SOEXT).$(RUBY_PROGRAM_VERSION)"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wno-tautological-compare -Wno-parentheses-equality -Wno-constant-logical-operand -Wno-self-assign -Wunused-variable -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations -Wno-packed-bitfield-compat -Wsuggest-attribute=noreturn -Wsuggest-attribute=format -Wimplicit-fallthrough=0"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wdeclaration-after-statement -Wdeprecated-declarations -Wduplicated-cond -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wrestrict -Wwrite-strings -Wimplicit-fallthrough=0 -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wsuggest-attribute=format -Wsuggest-attribute=noreturn -Wunused-variable"
   CONFIG["debugflags"] = "-ggdb3"
-  CONFIG["optflags"] = "-O3 -fno-fast-math"
+  CONFIG["optflags"] = "-O3"
   CONFIG["NULLCMD"] = ":"
+  CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
+  CONFIG["MJIT_SUPPORT"] = "yes"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
@@ -112,6 +115,7 @@ module RbConfig
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip -S -x"
+  CONFIG["SOEXT"] = "so"
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "LD_PRELOAD"
   CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
@@ -129,6 +133,8 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = ""
   CONFIG["DLDFLAGS"] = "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -Wl,--compress-debug-sections=zlib"
   CONFIG["ALLOCA"] = ""
+  CONFIG["MATHN"] = "yes"
+  CONFIG["dsymutil"] = ""
   CONFIG["codesign"] = ""
   CONFIG["POSTLINK"] = ":"
   CONFIG["WERRORFLAG"] = "-Werror"
@@ -138,8 +144,7 @@ module RbConfig
   CONFIG["RMDIR"] = "rmdir --ignore-fail-on-non-empty"
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
-  CONFIG["PKG_CONFIG"] = "/usr/bin/pkg-config"
-  CONFIG["PYTHON"] = ""
+  CONFIG["PKG_CONFIG"] = ""
   CONFIG["DOXYGEN"] = "doxygen"
   CONFIG["DOT"] = "dot"
   CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
@@ -160,7 +165,7 @@ module RbConfig
   CONFIG["AR"] = "ar"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc (GCC) 8.3.0\nCopyright (C) 2018 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "gcc (GCC) 8.2.1 20181127\nCopyright (C) 2018 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
@@ -172,17 +177,13 @@ module RbConfig
   CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt"
+  CONFIG["CXXFLAGS"] = "-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt"
+  CONFIG["CXX"] = "g++"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-D_FORTIFY_SOURCE=2 $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -fstack-protector -rdynamic -Wl,-export-dynamic"
-  CONFIG["CFLAGS"] = "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fPIC"
-  CONFIG["CXX"] = "g++"
+  CONFIG["LDFLAGS"] = "-L. -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -fstack-protector-strong -rdynamic -Wl,-export-dynamic"
+  CONFIG["CFLAGS"] = "-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt -fPIC"
   CONFIG["CC"] = "gcc"
-  CONFIG["NACL_LIB_PATH"] = ""
-  CONFIG["NACL_SDK_VARIANT"] = ""
-  CONFIG["NACL_SDK_ROOT"] = ""
-  CONFIG["NACL_TOOLCHAIN"] = ""
   CONFIG["target_os"] = "linux"
   CONFIG["target_vendor"] = "pc"
   CONFIG["target_cpu"] = "x86_64"
@@ -198,14 +199,17 @@ module RbConfig
   CONFIG["build_vendor"] = "pc"
   CONFIG["build_cpu"] = "x86_64"
   CONFIG["build"] = "x86_64-pc-linux-gnu"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.10"
+  CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.6.2"
+  CONFIG["HAVE_GIT"] = "no"
+  CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
-  CONFIG["LIBS"] = "-lpthread -lgmp -ldl -lcrypt -lm "
+  CONFIG["LIBS"] = "-lm "
   CONFIG["ECHO_T"] = ""
   CONFIG["ECHO_N"] = "-n"
   CONFIG["ECHO_C"] = ""
@@ -221,7 +225,6 @@ module RbConfig
   CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["includedir"] = "$(prefix)/include"
-  CONFIG["runstatedir"] = "$(localstatedir)/run"
   CONFIG["localstatedir"] = "$(DESTDIR)/var"
   CONFIG["sharedstatedir"] = "$(DESTDIR)/var/lib"
   CONFIG["sysconfdir"] = "$(DESTDIR)/etc"
@@ -239,7 +242,8 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["UNICODE_VERSION"] = "9.0.0"
+  CONFIG["UNICODE_VERSION"] = "12.0.0"
+  CONFIG["UNICODE_EMOJI_VERSION"] = "12.0"
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
   # Almost same with CONFIG. MAKEFILE_CONFIG has other variable
@@ -299,6 +303,38 @@ module RbConfig
     RbConfig::expand(val)
   end
 
+  # :nodoc:
+  # call-seq:
+  #
+  #   RbConfig.fire_update!(key, val)               -> string
+  #   RbConfig.fire_update!(key, val, mkconf, conf) -> string
+  #
+  # updates +key+ in +mkconf+ with +val+, and all values depending on
+  # the +key+ in +mkconf+.
+  #
+  #   RbConfig::MAKEFILE_CONFIG.values_at("CC", "LDSHARED") # => ["gcc", "$(CC) -shared"]
+  #   RbConfig::CONFIG.values_at("CC", "LDSHARED")          # => ["gcc", "gcc -shared"]
+  #   RbConfig.fire_update!("CC", "gcc-8")                  # => ["CC", "LDSHARED"]
+  #   RbConfig::MAKEFILE_CONFIG.values_at("CC", "LDSHARED") # => ["gcc-8", "$(CC) -shared"]
+  #   RbConfig::CONFIG.values_at("CC", "LDSHARED")          # => ["gcc-8", "gcc-8 -shared"]
+  #
+  # returns updated keys list, or +nil+ if nothing changed.
+  def RbConfig.fire_update!(key, val, mkconf = MAKEFILE_CONFIG, conf = CONFIG)
+    return if (old = mkconf[key]) == val
+    mkconf[key] = val
+    keys = [key]
+    deps = []
+    begin
+      re = Regexp.new("\\$\\((?:%1$s)\\)|\\$\\{(?:%1$s)\\}" % keys.join('|'))
+      deps |= keys
+      keys.clear
+      mkconf.each {|k,v| keys << k if re =~ v}
+    end until keys.empty?
+    deps.each {|k| conf[k] = mkconf[k].dup}
+    deps.each {|k| expand(conf[k])}
+    deps
+  end
+
   # call-seq:
   #
   #   RbConfig.ruby -> path
